@@ -28,6 +28,8 @@ DifferenceDict, DictMethods
 __all__ = [
 	# .juniper
 	'Juniper',
+	# Jset
+	'JSet',
 	# .addressing
 	'IPv4', 'IPv6', 'addressing', 'Validation', 'get_summaries', 'isSubset',
 	'binsubnet', 'bin2dec', 'bin2decmask', 'to_dec_mask', 'bin_mask',
@@ -35,11 +37,14 @@ __all__ = [
 	'Default', 'Container', 'Numeric', 'DifferenceDict', 
 	'STR', 'IO', 'LST', 'DIC', 'LOG', 'DB', 'IP', 'XL_READ', 'XL_WRITE', 
 	'DictMethods', 'Multi_Execution',
+	# .convertdict
+	'ConvDict',
 	]
 
-__version__ = "0.0.7"
+__version__ = "0.0.8"
 
 from .juniper import Juniper
+from .jset import JSet
 
 from .addressing import (
 	IPv4, IPv6, addressing, Validation, get_summaries, isSubset,
@@ -52,4 +57,4 @@ from .gpl import (Default, Container, Numeric,
 	Multi_Execution,
 	)
 
-# END OF PROG
+from .convertdict import ConvDict
\ No newline at end of file
